/**********************************************************************************************/
/* VSDK.h																					  */
/*                                                                       					  */
/* 										                                   					  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002                                       					  */
/* All Rights Reserved.                                                 					  */
/**********************************************************************************************/

#ifndef __VSDK_h
	#define __VSDK_h

#pragma once

/*
	This file has 2 significant purpose:
	1) It allows you easy include all VSDK headers into your precompiled header.
	2) It hides VSDK headers, i.e. if later will be added/removed/renamed a header
		file of VSDK, you will not need update your sources on this chnages.
		So it is recommended to #include only this file in your sources.
*/

/**********************************************************************************************/
// Macros to choose between framework style and normal style.
// On default Projectbuilder uses framework style, but other compilers normal style.
//
// If you want to use VSDK.Framework with CodeWarrior you need BEFORE this file set 
// macro VSDK_FRAMEWORK_STYLE to 1.
// 

#ifndef VSDK_FRAMEWORK_STYLE
#	ifdef __GNUC__ // we work under ProjectBuilder, on default it use VSDK.framework
#		define VSDK_FRAMEWORK_STYLE 1
#	else
#		define VSDK_FRAMEWORK_STYLE 0
#	endif
#endif


/**********************************************************************************************/
#if VSDK_FRAMEWORK_STYLE 

	#include <Carbon/Carbon.h>

	#include <VSDK/FBL.h>

	#include <VSDK/FBL_Array.h>
	#include <VSDK/FBL_ArraySet.h>
	#include <VSDK/FBL_ArraySetIterator.h>

	#include <VSDK/FBL_BitSet.h>
	#include <VSDK/FBL_BitSetIterator.h>

	#include <VSDK/FBL_ByteSwap.h>
	#include <VSDK/FBL_Compressor.h>
	#include <VSDK/FBL_Critical.h>
	#include <VSDK/FBL_CriticalNative.h>
	#include <VSDK/FBL_DateTimeEncode.h>
	#include <VSDK/FBL_Deleter.h>
	#include <VSDK/FBL_Encryption.h>
	#include <VSDK/FBL_Exceptions.h>
	#include <VSDK/FBL_Formula.h>
	#include <VSDK/FBL_Globals.h>
	#include <VSDK/FBL_LanguageManager.h>
	#include <VSDK/FBL_MaxFormula.h>
	#include <VSDK/FBL_MinFormula.h>
	#include <VSDK/FBL_Progresser.h>
	#include <VSDK/FBL_ReplaceFormula.h>
	#include <VSDK/FBL_Set.h>
	#include <VSDK/FBL_SetIterator.h>
	#include <VSDK/FBL_Sharable.h>
	#include <VSDK/FBL_String.h>
	#include <VSDK/FBL_StringUtilities.h>
	#include <VSDK/FBL_SumFormula.h>
	#include <VSDK/FBL_SyncObjects.h>
	#include <VSDK/FBL_SyncObjectsNative.h>
	#include <VSDK/FBL_Task.h>
	#include <VSDK/FBL_Thread.h>
	#include <VSDK/FBL_ThreadNative.h>
	#include <VSDK/FBL_ToFromString.h>
	#include <VSDK/FBL_Version.h>
	#include <VSDK/MemPtr.h>

	#include <VSDK/OBL.h>
	#include <VSDK/OBL_Dump.h>
	#include <VSDK/OBL_Exceptions.h>
	#include <VSDK/OBL_SQL.h>

	#include <VSDK/VDK_BaseObject.h>
	#include <VSDK/VDK_BLOB.h>
	#include <VSDK/VDK_Boolean.h>
	#include <VSDK/VDK_Byte.h>
	#include <VSDK/VDK_Cursor.h>
	#include <VSDK/VDK_DataBase.h>
	#include <VSDK/VDK_Date.h>
	#include <VSDK/VDK_DateTime.h>
	#include <VSDK/VDK_DescriptionFile.h>
	#include <VSDK/VDK_Double.h>
	#include <VSDK/VDK_Field.h>
	#include <VSDK/VDK_FixedBinary.h>
	#include <VSDK/VDK_Float.h>
	#include <VSDK/VDK_Globals.h>
	#include <VSDK/VDK_ImportExport.h>
	#include <VSDK/VDK_Link.h>
	#include <VSDK/VDK_LLong.h>
	#include <VSDK/VDK_Long.h>
	#include <VSDK/VDK_Medium.h>
	#include <VSDK/VDK_ObjectPtr.h>
	#include <VSDK/VDK_Picture.h>
	#include <VSDK/VDK_Relation.h>
	#include <VSDK/VDK_SearchTree.h>
	#include <VSDK/VDK_Short.h>
	#include <VSDK/VDK_SortOrder.h>
	#include <VSDK/VDK_String.h>
	#include <VSDK/VDK_Text.h>
	#include <VSDK/VDK_Time.h>
	#include <VSDK/VDK_ULLong.h>
	#include <VSDK/VDK_ULong.h>
	#include <VSDK/VDK_UMedium.h>
	#include <VSDK/VDK_UShort.h>
	#include <VSDK/VDK_VarBinary.h>
	#include <VSDK/VDK_VarChar.h>

#else // VSDK_FRAMEWORK_STYLE

	#include <FBL.h>

	#include <FBL_Array.h>
	#include <FBL_ArraySet.h>
	#include <FBL_ArraySetIterator.h>

	#include <FBL_BitSet.h>
	#include <FBL_BitSetIterator.h>

	#include <FBL_ByteSwap.h>
	#include <FBL_Compressor.h>
	#include <FBL_Critical.h>
	#include <FBL_CriticalNative.h>
	#include <FBL_DateTimeEncode.h>
	#include <FBL_Deleter.h>
	#include <FBL_Encryption.h>
	#include <FBL_Exceptions.h>
	#include <FBL_Formula.h>
	#include <FBL_Globals.h>
	#include <FBL_LanguageManager.h>
	#include <FBL_MaxFormula.h>
	#include <FBL_MinFormula.h>
	#include <FBL_Progresser.h>
	#include <FBL_ReplaceFormula.h>
	#include <FBL_Set.h>
	#include <FBL_SetIterator.h>
	#include <FBL_Sharable.h>
	#include <FBL_String.h>
	#include <FBL_StringUtilities.h>
	#include <FBL_SumFormula.h>
	#include <FBL_SyncObjects.h>
	#include <FBL_SyncObjectsNative.h>
	#include <FBL_Task.h>
	#include <FBL_Thread.h>
	#include <FBL_ThreadNative.h>
	#include <FBL_ToFromString.h>
	#include <FBL_Version.h>
	#include <MemPtr.h>

	#include <OBL.h>
	#include <OBL_Dump.h>
	#include <OBL_Exceptions.h>
	#include <OBL_SQL.h>

#ifdef VSDK_CLIENT

	#include <VDKC_BaseObject.h>
	#include <VDKC_BLOB.h>
	#include <VDKC_Boolean.h>
	#include <VDKC_Byte.h>
	#include <VDKC_Cursor.h>
	#include <VDKC_DataBase.h>
	#include <VDKC_Date.h>
	#include <VDKC_DateTime.h>
	#include <VDKC_Double.h>
	#include <VDKC_Field.h>
	#include <VDKC_FixedBinary.h>
	#include <VDKC_Float.h>
	#include <VDKC_Globals.h>
	#include <VDKC_Link.h>
	#include <VDKC_LLong.h>
	#include <VDKC_Long.h>
	#include <VDKC_Medium.h>
	#include <VDKC_ObjectPtr.h>
	#include <VDKC_Picture.h>
	#include <VDKC_Short.h>
	#include <VDKC_String.h>
	#include <VDKC_Text.h>
	#include <VDKC_Time.h>
	#include <VDKC_ULLong.h>
	#include <VDKC_ULong.h>
	#include <VDKC_UMedium.h>
	#include <VDKC_UShort.h>
	#include <VDKC_VarBinary.h>
	#include <VDKC_VarChar.h>
	#include <VDKC_Server.h>
	#include <VDKC_DatabaseInfo.h>
	#include <VDKC_ClientInfo.h>

#else // #ifdef VSDK_CLIENT

	#include <VDK_BaseObject.h>
	#include <VDK_BLOB.h>
	#include <VDK_Boolean.h>
	#include <VDK_Byte.h>
	#include <VDK_Cursor.h>
	#include <VDK_DataBase.h>
	#include <VDK_Date.h>
	#include <VDK_DateTime.h>
	#include <VDK_DescriptionFile.h>
	#include <VDK_Double.h>
	#include <VDK_Field.h>
	#include <VDK_FixedBinary.h>
	#include <VDK_Float.h>
	#include <VDK_Globals.h>
	#include <VDK_ImportExport.h>
	#include <VDK_Link.h>
	#include <VDK_LLong.h>
	#include <VDK_Long.h>
	#include <VDK_Medium.h>
	#include <VDK_ObjectPtr.h>
	#include <VDK_Picture.h>
	#include <VDK_Relation.h>
	#include <VDK_SearchTree.h>
	#include <VDK_Short.h>
	#include <VDK_SortOrder.h>
	#include <VDK_String.h>
	#include <VDK_Text.h>
	#include <VDK_Time.h>
	#include <VDK_ULLong.h>
	#include <VDK_ULong.h>
	#include <VDK_UMedium.h>
	#include <VDK_UShort.h>
	#include <VDK_VarBinary.h>
	#include <VDK_VarChar.h>

#endif // #ifdef VSDK_CLIENT

#endif // VSDK_FRAMEWORK_STYLE 


/**********************************************************************************************/
#endif // #ifndef __VSDK_h
